@@ -15,26 +15,21 @@
 """
 __docformat__ = 'restructuredtext'
 
-from zope.component import adapts
-from zope.interface import implements
-from zope.location.interfaces import ILocation
+from zope.interface import implementer
 from zope.location.location import inside
 
 try:
     from zope.copy.interfaces import ICopyHook, ResumeCopy
-except ImportError:
+except ImportError: #pragma NO COVER
     raise NotImplementedError("zope.location.pickling is not supported "
         "because zope.copy is not available")
 
 
+@implementer(ICopyHook)
 class LocationCopyHook(object):
     """Copy hook to preserve copying referenced objects that are not
     located inside object that's being copied.
     """
-    
-    adapts(ILocation)
-    implements(ICopyHook)
-    
     def __init__(self, context):
         self.context = context
     
@@ -42,13 +37,3 @@ class LocationCopyHook(object):
         if not inside(self.context, toplevel):
             return self.context
         raise ResumeCopy
-
-# BBB 2009-09-02
-# The locationCopy was replaced by more generic "clone" function
-# in the zope.copy package. This reference may be removed someday.
-from zope.copy import clone as locationCopy
-
-# BBB 2009-09-02
-# The CopyPersistent was made more generic and moved to the
-# zope.copy package. This reference may be removed someday.
-from zope.copy import CopyPersistent
